@@ -2,12 +2,12 @@ package Kafka::MockIO;
 
 =head1 NAME
 
-Kafka::MockIO - object interface to simulate the socket communications with
-the Apache Kafka server.
+Kafka::MockIO - object interface to simulate communications with the Apache Kafka
+server via socket.
 
 =head1 VERSION
 
-This documentation refers to C<Kafka::MockIO> version 0.800_17 .
+This documentation refers to C<Kafka::MockIO> version 0.8001_1 .
 
 =cut
 
@@ -19,7 +19,7 @@ use warnings;
 
 # ENVIRONMENT ------------------------------------------------------------------
 
-our $VERSION = '0.800_17';
+our $VERSION = '0.8001_1';
 
 #-- load the modules -----------------------------------------------------------
 
@@ -91,7 +91,7 @@ Simplistically emulates interaction with kafka server.
 
 =back
 
-Examples see C<t/??_mock_io.t>.
+Examples see C<t/*_mock_io.t>.
 
 =cut
 
@@ -105,6 +105,13 @@ The following constants are available for export
 
 =cut
 
+=head3 C<$TOPIC>
+
+Topic name.
+
+=cut
+const our $TOPIC                    => 'mytopic';
+
 =head3 C<$PARTITION>
 
 0 - Partition number.
@@ -161,7 +168,7 @@ my $decoded_produce_response = {
     CorrelationId                           => 0,           # for example
     topics                                  => [
         {
-            TopicName                       => 'mytopic',   # for example
+            TopicName                       => $TOPIC,      # for example
             partitions                      => [
                 {
                     Partition               => $PARTITION,
@@ -177,7 +184,7 @@ my $decoded_fetch_response = {
     CorrelationId                           => 0,           # for example
     topics                                  => [
         {
-            TopicName                       => 'mytopic',   # for example
+            TopicName                       => $TOPIC,      # for example
             partitions                      => [
                 {
                     Partition               => $PARTITION,
@@ -209,7 +216,7 @@ my $decoded_offset_response = {
     CorrelationId                       => 0,           # for example
     topics                              => [
         {
-            TopicName                   => 'mytopic',   # for example
+            TopicName                   => $TOPIC,      # for example
             PartitionOffsets            => [
                 {
                     Partition           => $PARTITION,
@@ -245,7 +252,7 @@ my $decoded_metadata_response = {
     TopicMetadata                       => [
         {
             ErrorCode                   => 0,
-            TopicName                   => 'mytopic',   # for example
+            TopicName                   => $TOPIC,      # for example
             PartitionMetadata           => [
                 {
                     ErrorCode           => 0,
@@ -438,7 +445,8 @@ sub send {
     ( my $len = length( $message .= q{} ) ) <= $MAX_SOCKET_REQUEST_BYTES
         or Kafka::IO::_error( $self, $ERROR_MISMATCH_ARGUMENT, $description );
 
-    Kafka::IO::_debug_msg( $self, 'Request to', 'green', $message ) if $Kafka::IO::DEBUG;
+    Kafka::IO::_debug_msg( $self, $message, 'Request to', 'green' )
+        if Kafka::IO->debug_level == 1;
 
     if ( exists $_special_cases{ $message } ) {
         $encoded_response = $_special_cases{ $message };
@@ -605,8 +613,8 @@ sub receive {
 
     my $message = substr( $encoded_response, 0, $length, q{} );
 
-    Kafka::IO::_debug_msg( $self, 'Response from', 'yellow', $message )
-        if $Kafka::IO::DEBUG;
+    Kafka::IO::_debug_msg( $self, $message, 'Response from', 'yellow' )
+        if Kafka::IO->debug_level == 1;
 
     return \$message;
 }
@@ -731,6 +739,8 @@ Alexander Solovey
 
 Jeremy Jordan
 
+Sergiy Zuban
+
 Vlad Marchenko
 
 =head1 COPYRIGHT AND LICENSE
