@@ -6,7 +6,7 @@ Kafka::TestInternals - Constants and functions used in the tests.
 
 =head1 VERSION
 
-This documentation refers to C<Kafka::TestInternals> version 0.800_17 .
+This documentation refers to C<Kafka::TestInternals> version 0.8001_1 .
 
 =cut
 
@@ -18,7 +18,7 @@ use warnings;
 
 # ENVIRONMENT ------------------------------------------------------------------
 
-our $VERSION = '0.800_17';
+our $VERSION = '0.8001_1';
 
 use Exporter qw(
     import
@@ -286,7 +286,7 @@ const our @not_array => (
 =head3 C<@not_topics_array>
 
 The values do not correspond to a 'topics' ARRAY reference.
-For 'topics' ARRAY examples see C<t/??_decode_encode.t>.
+For 'topics' ARRAY examples see C<t/*_decode_encode.t>.
 
 =cut
 our @not_topics_array;
@@ -462,6 +462,8 @@ Alexander Solovey
 
 Jeremy Jordan
 
+Sergiy Zuban
+
 Vlad Marchenko
 
 =head1 COPYRIGHT AND LICENSE
